@@ -13,7 +13,13 @@
 ##############################################################################
 """z3c.zalchemy integrates sqlalchemy into zope 3
 
-$Id: __init__.py 67202 2006-04-21 10:25:35Z dobe $
+$Id: __init__.py 122476 2011-08-05 09:27:26Z wosc $
 """
 __docformat__ = "reStructuredText"
 
+# namespace package boilerplate
+try:
+    __import__('pkg_resources').declare_namespace(__name__)
+except ImportError, e:
+    from pkgutil import extend_path
+    __path__ = extend_path(__path__, __name__)
